========================
Dataset Tools
========================

This is a collection of tools for working with the datasets referenced from this repository.

Different packages are available for

* Downloading the datasets and extracting them
* Processing the datasets generally, like resizing all images in a directory or splitting it into train/validation/test-sets.
* Processing specific datasets, e.g. generating images from the raw HOMUS dataset.